==> edge-login-ui-rn-3.11.2.tgz: package/lib/components/scenes/RecoveryLoginScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { asMaybeOtpError, asMaybePasswordError } from 'edge-core-js';
import * as React from 'react';
import { useState } from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { completeLogin } from '../../actions/LoginCompleteActions';
import { lstrings } from '../../common/locales/strings';
import { useImports } from '../../hooks/useImports';
import { useDispatch } from '../../types/ReduxTypes';
import { attemptLogin } from '../../util/loginAttempt';
import { Tile } from '../common/Tile';
import { WarningCard } from '../common/WarningCard';
import { DateModal } from '../modals/DateModal';
import { TextInputModal } from '../modals/TextInputModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const RecoveryLoginScene = (props) => {
    const { route } = props;
    const { recoveryKey, userQuestions: questions, username } = route.params;
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const { accountOptions, context, onPerfEvent } = useImports();
    const answerPrompt = lstrings.your_answer_label;
    const showCaseSensitivityWarning = questions.some(q => q.startsWith('text:') || !q.includes(':'));
    const [answers, setAnswers] = useState([]);
    const saveOtpError = (otpAttempt, otpError) => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'otpError', params: { otpAttempt, otpError } }
        });
    };
    const showDatePickerModal = (index) => {
        const now = new Date();
        Airship.show(bridge => (React.createElement(DateModal, { bridge: bridge, initialValue: now }))).then(answer => {
            const date = answer.toISOString().split('T')[0];
            answers[index] = date;
            setAnswers([...answers]);
        });
    };
    const showTextInputModal = (index) => {
        let minLengthString = questions[index].split(':')[1];
        if (minLengthString == null || minLengthString.trim() === '')
            minLengthString = '0';
        const minLength = parseInt(minLengthString);
        const validateAnswer = (answer) => __awaiter(void 0, void 0, void 0, function* () {
            return answer.length >= minLength
                ? true
                : sprintf(lstrings.min_length_error, minLength);
        });
        Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, title: sprintf(lstrings.recovery_answer, index + 1), inputLabel: lstrings.recovery_answer_placeholder, returnKeyType: "go", autoCapitalize: "none", autoCorrect: false, autoFocus: true, onSubmit: validateAnswer }))).then(text => {
            if (text == null)
                return;
            answers[index] = text;
            setAnswers([...answers]);
        });
    };
    const handleAnswer = (index) => () => {
        if (questions[index] == null)
            return;
        if (questions[index].startsWith('date:')) {
            showDatePickerModal(index);
        }
        else if (questions[index].startsWith('text:')) {
            showTextInputModal(index);
        }
        else {
            // Legacy Questions
            showTextInputModal(index);
        }
    };
    const handleSubmit = () => __awaiter(void 0, void 0, void 0, function* () {
        const okAnswers = answers.filter((a) => a != null);
        const attempt = {
            type: 'recovery',
            recoveryKey,
            username,
            answers: okAnswers
        };
        try {
            const account = yield attemptLogin(context, attempt, accountOptions, onPerfEvent);
            yield dispatch(completeLogin(account));
        }
        catch (error) {
            const otpError = asMaybeOtpError(error);
            if (otpError != null) {
                return saveOtpError(attempt, otpError);
            }
            const passwordError = asMaybePasswordError(error);
            if (passwordError != null) {
                return showError(lstrings.recovery_error);
            }
            showError(error instanceof Error ? error.message : 'Unknown error');
        }
    });
    const renderQuestionAnswer = (index) => {
        var _a, _b, _c;
        return (React.createElement(View, null,
            React.createElement(Tile, { type: "static", title: sprintf(lstrings.recovery_question, index + 1), body: (_b = (_a = questions[index]) === null || _a === void 0 ? void 0 : _a.split(':').slice(-1)[0]) !== null && _b !== void 0 ? _b : sprintf(lstrings.recovery_question, index + 1) }),
            React.createElement(Tile, { type: "touchable", title: sprintf(lstrings.recovery_answer, index + 1), body: (_c = answers[index]) !== null && _c !== void 0 ? _c : answerPrompt, onPress: handleAnswer(index) })));
    };
    const renderForm = () => {
        return (React.createElement(View, { style: styles.formContainer },
            renderQuestionAnswer(0),
            renderQuestionAnswer(1),
            renderWarning()));
    };
    const renderWarning = () => {
        return showCaseSensitivityWarning ? (React.createElement(WarningCard, { title: lstrings.answer_case_sensitive, marginRem: 1 })) : null;
    };
    const renderSubmitButton = () => {
        return (React.createElement(View, { style: styles.buttonsContainer },
            React.createElement(MainButton, { label: lstrings.submit, marginRem: [1, 0.5], onPress: handleSubmit, disabled: answers.length < questions.length || answers.some(a => a == null), type: "primary" })));
    };
    return (React.createElement(ThemedScene, { paddingRem: 0, onBack: () => dispatch({
            type: 'NAVIGATE',
            data: { name: 'passwordLogin', params: { username } }
        }) },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            renderForm(),
            renderSubmitButton())));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        marginTop: theme.rem(1.5)
    },
    formContainer: {
        width: '100%',
        marginBottom: theme.rem(1)
    },
    buttonsContainer: {
        marginHorizontal: theme.rem(1),
        marginBottom: theme.rem(1)
    }
}));

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/scenes/RecoveryLoginScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { asMaybeOtpError, asMaybePasswordError } from 'edge-core-js';
import * as React from 'react';
import { useState } from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { completeLogin } from '../../actions/LoginCompleteActions';
import { lstrings } from '../../common/locales/strings';
import { useImports } from '../../hooks/useImports';
import { useDispatch } from '../../types/ReduxTypes';
import { attemptLogin } from '../../util/loginAttempt';
import { Tile } from '../common/Tile';
import { WarningCard } from '../common/WarningCard';
import { DateModal } from '../modals/DateModal';
import { TextInputModal } from '../modals/TextInputModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const RecoveryLoginScene = (props) => {
    const { route } = props;
    const { recoveryKey, userQuestions: questions, username } = route.params;
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const { accountOptions, context, onPerfEvent } = useImports();
    const answerPrompt = lstrings.your_answer_label;
    const showCaseSensitivityWarning = questions.some(q => q.startsWith('text:') || !q.includes(':'));
    const [answers, setAnswers] = useState([]);
    const saveOtpError = (otpAttempt, otpError) => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'otpError', params: { otpAttempt, otpError } }
        });
    };
    const showDatePickerModal = (index) => {
        const now = new Date();
        Airship.show(bridge => (React.createElement(DateModal, { bridge: bridge, initialValue: now }))).then(answer => {
            const date = answer.toISOString().split('T')[0];
            answers[index] = date;
            setAnswers([...answers]);
        });
    };
    const showTextInputModal = (index) => __awaiter(void 0, void 0, void 0, function* () {
        let minLengthString = questions[index].split(':')[1];
        if (minLengthString == null || minLengthString.trim() === '')
            minLengthString = '0';
        const minLength = parseInt(minLengthString);
        const validateAnswer = (answer) => __awaiter(void 0, void 0, void 0, function* () {
            return answer.length >= minLength
                ? true
                : sprintf(lstrings.min_length_error, minLength);
        });
        const text = yield Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, title: sprintf(lstrings.recovery_answer, index + 1), inputLabel: lstrings.recovery_answer_placeholder, returnKeyType: "go", autoCapitalize: "none", autoCorrect: false, autoFocus: true, onSubmit: validateAnswer })));
        if (text == null)
            return;
        answers[index] = text;
        setAnswers([...answers]);
    });
    const handleAnswer = (index) => () => __awaiter(void 0, void 0, void 0, function* () {
        if (questions[index] == null)
            return;
        if (questions[index].startsWith('date:')) {
            showDatePickerModal(index);
        }
        else if (questions[index].startsWith('text:')) {
            showTextInputModal(index);
        }
        else {
            // Legacy Questions
            showTextInputModal(index);
        }
    });
    const handleSubmit = () => __awaiter(void 0, void 0, void 0, function* () {
        const okAnswers = answers.filter((a) => a != null);
        const attempt = {
            type: 'recovery',
            recoveryKey,
            username,
            answers: okAnswers
        };
        try {
            const account = yield attemptLogin(context, attempt, accountOptions, onPerfEvent);
            yield dispatch(completeLogin(account));
        }
        catch (error) {
            const otpError = asMaybeOtpError(error);
            if (otpError != null) {
                return saveOtpError(attempt, otpError);
            }
            const passwordError = asMaybePasswordError(error);
            if (passwordError != null) {
                return showError(lstrings.recovery_error);
            }
            showError(error instanceof Error ? error.message : 'Unknown error');
        }
    });
    const renderQuestionAnswer = (index) => {
        var _a, _b, _c;
        return (React.createElement(View, null,
            React.createElement(Tile, { type: "static", title: sprintf(lstrings.recovery_question, index + 1), body: (_b = (_a = questions[index]) === null || _a === void 0 ? void 0 : _a.split(':').slice(-1)[0]) !== null && _b !== void 0 ? _b : sprintf(lstrings.recovery_question, index + 1) }),
            React.createElement(Tile, { type: "touchable", title: sprintf(lstrings.recovery_answer, index + 1), body: (_c = answers[index]) !== null && _c !== void 0 ? _c : answerPrompt, onPress: handleAnswer(index) })));
    };
    const renderForm = () => {
        return (React.createElement(View, { style: styles.formContainer },
            renderQuestionAnswer(0),
            renderQuestionAnswer(1),
            renderWarning()));
    };
    const renderWarning = () => {
        return showCaseSensitivityWarning ? (React.createElement(WarningCard, { title: lstrings.answer_case_sensitive, marginRem: 1 })) : null;
    };
    const renderSubmitButton = () => {
        return (React.createElement(View, { style: styles.buttonsContainer },
            React.createElement(MainButton, { label: lstrings.submit, marginRem: [1, 0.5], onPress: handleSubmit, disabled: answers.length < questions.length || answers.some(a => a == null), type: "primary" })));
    };
    return (React.createElement(ThemedScene, { paddingRem: 0, onBack: () => dispatch({
            type: 'NAVIGATE',
            data: { name: 'passwordLogin', params: { username } }
        }) },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            renderForm(),
            renderSubmitButton())));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        marginTop: theme.rem(1.5)
    },
    formContainer: {
        width: '100%',
        marginBottom: theme.rem(1)
    },
    buttonsContainer: {
        marginHorizontal: theme.rem(1),
        marginBottom: theme.rem(1)
    }
}));
